Coverage for F:\DEV\EMIZ\emiz\__init__.py: 75%

# Coverage for F:\DEV\EMIZ\emiz\__init__.py : 75%

## 8 statements 6 run 2 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 | # coding=utf-8 from .miz import Miz, Mission from .parking_spots import parkings from pkg_resources import get_distribution, DistributionNotFound try: __version__ = get_distribution('emiz').version except DistributionNotFound: # package is not installed __version__ = 'not installed' __version__ = None